rehh-package: Data Only: Searching for Footprints of Selection using...

rehh.data-packageR Documentation

Data Only: Searching for Footprints of Selection using Haplotype Homozygosity Based Tests Description: Contains example data for the 'rehh' package.

Description

Contains example data for the package rehh.

Details

Package: rehh.data
Version: 1.0.0
License: GPL(>=2)

Index:

wgscan.cgu              Whole genome scan results for the CGU
                        (Creole from Guadeloupe island)
wgscan.eut              Whole genome scan results for a pool of
                        European taurine cattle

References

Gautier M., Klassmann A., and Vitalis R. (2017). rehh 2.0: a reimplementation of the R package rehh to detect positive selection from haplotype structure. Molecular Ecology Resources, 17, 78–90.

Gautier M. and Vitalis R. (2012). rehh: An R package to detect footprints of selection in genome-wide SNP data from haplotype structure. Bioinformatics, 28(8), 1176–1177.

Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World Creole cattle breed. Molecular Ecology, 20, 3128–3143.


rehh.data documentation built on May 4, 2026, 5:06 p.m.